@@ -1,5 +1,6 @@
 ## ----include=FALSE-------------------------------------------------------
 library(checkmate)
+do.eval = requireNamespace("microbenchmark", quietly = TRUE)
 
 ## ------------------------------------------------------------------------
 fact <- function(n, method = "stirling") {
@@ -64,7 +65,7 @@ f <- function(x) {
 #    qexpect(x, "N100[0,1]")
 #  })
 
-## ----dev="svg",fig.width=6,fig.height=4----------------------------------
+## ----dev="svg",fig.width=6,fig.height=4,eval=do.eval---------------------
 library(ggplot2)
 library(microbenchmark)
 
@@ -76,7 +77,7 @@ mb = microbenchmark(r(x), cm(x), cmq(x))
 print(mb)
 autoplot(mb)
 
-## ----dev="svg",fig.width=6,fig.height=4----------------------------------
+## ----dev="svg",fig.width=6,fig.height=4,eval=do.eval---------------------
 x = runif(1000)
 r = function(x) stopifnot(is.numeric(x) && length(x) == 1000 && all(!is.na(x) & x >= 0 & x <= 1))
 cm = function(x) assertNumeric(x, len = 1000, any.missing = FALSE, lower = 0, upper = 1)
@@ -85,7 +86,7 @@ mb = microbenchmark(r(x), cm(x), cmq(x))
 print(mb)
 autoplot(mb)
 
-## ----dev="svg",fig.width=6,fig.height=4----------------------------------
+## ----dev="svg",fig.width=6,fig.height=4,eval=do.eval---------------------
 x = sample(letters, 10000, replace = TRUE)
 r = function(x) stopifnot(is.character(x) && !any(is.na(x)) && all(nchar(x) > 0))
 cm = function(x) assertCharacter(x, any.missing = FALSE, min.chars = 1)
@@ -94,7 +95,7 @@ mb = microbenchmark(r(x), cm(x), cmq(x))
 print(mb)
 autoplot(mb)
 
-## ----dev="svg",fig.width=6,fig.height=4----------------------------------
+## ----dev="svg",fig.width=6,fig.height=4,eval=do.eval---------------------
 N = 10000
 x = data.frame(a = runif(N), b = sample(letters[1:5], N, replace = TRUE), c = sample(c(FALSE, TRUE), N, replace = TRUE))
 r = function(x) is.data.frame(x) && !any(sapply(x, function(x) any(is.na(x))))
