@@ -27,9 +27,9 @@ static Rboolean is_integerish_complex(SEXP x, const double tol) {
     return TRUE;
 }
 
-Rboolean isIntegerish(SEXP x, double tol) {
+Rboolean isIntegerish(SEXP x, const double tol, Rboolean logicals_ok) {
     switch(TYPEOF(x)) {
-        case LGLSXP: return TRUE;
+        case LGLSXP: return logicals_ok;
         case INTSXP: return TRUE;
         case REALSXP: return is_integerish_double(x, tol);
         case CPLXSXP: return is_integerish_complex(x, tol);
@@ -37,6 +37,6 @@ Rboolean isIntegerish(SEXP x, double tol) {
     return FALSE;
 }
 
-SEXP c_is_integerish(SEXP x, SEXP tolerance) {
-    return ScalarLogical(isIntegerish(x, REAL(tolerance)[0]));
+SEXP attribute_hidden c_is_integerish(SEXP x, SEXP tolerance) {
+    return ScalarLogical(isIntegerish(x, REAL(tolerance)[0], FALSE));
 }
