@@ -4,9 +4,10 @@
 #define USE_RINTERNALS
 #include <R.h>
 #include <Rinternals.h>
+#include <R_ext/Visibility.h>
 
-SEXP c_qassert(SEXP, SEXP, SEXP);
-SEXP c_qtest(SEXP, SEXP, SEXP, SEXP);
+SEXP attribute_hidden c_qassert(SEXP, SEXP, SEXP);
+SEXP attribute_hidden c_qtest(SEXP, SEXP, SEXP, SEXP);
 SEXP qassert(SEXP, const char *, const char *);
 Rboolean qtest(SEXP, const char *);
 
